Customize Styling
=================


If you want to customize your comments style do the following steps:
    1. Create a ``comment.css`` file inside your ``static/css`` directory.
    2. The new created file will overwrite the original file used in the app.
